# Keras Unsupervised
## Keras framework based unsupervised learning framework

On Keras, to develop semi-supervised learning and unsupervised learning via backpropagation, Keras framework based unsupervised learning libraries are necessary. For this reason, we focus on developing EBM (Energy based model) unsupervised learning modules, and autoencoder and GAN (Generative Adversarial Networks) modules which are based on unsupervised learning via backpropagation, and Keras layers and Tensorflow and Tensorflow-probability backend interfaces for unsupervied learning, and relevant utils. As a symbolic computation backend, Tensorflow is only applied.

# Tasks
- [X] Plain RBM, DBN.
- [X] GAN, Style-based GAN.
- [ ] AutoEncoder.
- [ ] First release, documentation.
- [ ] BM, DBM.
- [ ] Convolutional RBM, DBN.
- [ ] Second release, documentation.

## Tasks status

[GAN and Style-based GAN are tested and optimized.](https://github.com/tonandr/keras_unsupervised/tree/master/examples/style_based_gan)
